@@ -157,7 +157,7 @@ my $configure_php=sub {
          'yum -y install yum-utils','__display__');
    }
 #cleanup;
-   ($stdout,$stderr)=$handle->cmd("wget -qO- http://icanhazip.com");
+   ($stdout,$stderr)=$handle->cmd("wget -qO- https://icanhazip.com");
    $public_ip=$stdout if $stdout=~/^\d+\.\d+\.\d+\.\d+\s*/s;
    unless ($public_ip) {
       require Sys::Hostname;
